@@ -57,9 +57,9 @@ def usage(type):
         print(''' \033[92m	
                欢迎使用flexpepdock批量下载工具 @Author -nonobel 
                	usage : 
-                    (1)单个上传 ：flexpatch + 1.pdb
-                    (2)多个上传 ：flexpatch + 1.pdb  2.pdb  3.pdb (空格分开即可）
-                    (2)批量上传 ：flexpatch + pdb文件所在的目录地址  (会将目录底下的pdb全部上传分析)
+                    (1)单个上传 ：batchUpload + 1.pdb
+                    (2)多个上传 ：batchUpload + 1.pdb  2.pdb  3.pdb (空格分开即可）
+                    (2)批量上传 ：batchUpload + pdb文件所在的目录地址  (会将目录底下的pdb全部上传分析)
                 result: 输出的是 网站获取结果的链接，请自行复制保存查看
                 支持相对路径表达方式
                	\033[0m''')
